@@ -74,10 +74,12 @@ class WSGIFileServerApplication(object):
         url = urlparse(reconstruct_url(environ))
         
         if self.mount_point is not None:
-            split_url = url.path.split(self.mount_point, 1)
+            #split_url = url.path.split(self.mount_point, 1)
+            split_url = url[2].split(self.mount_point, 1)
             serve_file = split_url[1]
         else:
-            serve_file = url.path
+            #serve_file = url.path
+            serve_file = url[2]
         
         serve_file = serve_file.replace('%20', ' ')
         
@@ -141,4 +143,4 @@ class WSGIFileServerApplication(object):
             return content_type_table['fallback']
             
     def __call__(self, environ, start_response):
-        return self.handler(environ, start_response)
\ No newline at end of file
+        return self.handler(environ, start_response)
